@@ -17,7 +17,7 @@ use File::chdir;
 use Path::Class ();
 
 # ABSTRACT: Parallel SSH client
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 sub _local_default ($$)
@@ -229,13 +229,23 @@ sub server_command
 sub alias
 {
   my($self) = @_;
-  $self->config->alias( default => {} );
+  $self->config->alias( default => sub {
+    my %deprecated = $self->config->aliases( default => {} );
+    say STDERR "use of aliases key in configuration is deprecated, use alias instead"
+        if %deprecated;
+    \%deprecated;
+  });
 }
 
 sub cluster_list
 {
   my($self) = @_;
-  $self->config->cluster( default => {} );
+  $self->config->cluster( default => sub {
+    my %deprecated = $self->config->clusters( default => {} );
+    say STDERR "use of clusters key in configuration is deprecated, use cluster instead"
+        if %deprecated;
+    \%deprecated;
+  });
 }
 
 sub ret
@@ -525,7 +535,7 @@ App::clad - Parallel SSH client
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
